@@ -1,3 +1,6 @@
+from swap.common.logging import logger
+from swap.api.sequences.step_codes import StepCode
+
 class ServiceRequestPreHook:
     def call(self, input):
         return input
@@ -20,6 +23,9 @@ class ServiceOffersRequestPostHook:
         response = {}
 
         for chain_link_key, chain_link in chain_links.items():
+            if not chain_link.service_offers.items():
+                logger.info(f'No service offers received yet for service: {chain_link.service_catalogue_uuid}')
+                return StepCode.NoServiceOffersReceived
             service_offers = list(chain_link.service_offers.values())
             response[chain_link_key] = service_offers[0]
 
